@@ -173,6 +173,9 @@ class IAuthenticationPlugin(IAuthenticationPluginInfo, IPlugin):
     """Principal authentication plug-in interface"""
 
 
+ADMIN_AUTHENTICATION_PLUGIN_LABEL = _("System authentication plug-in")
+
+
 class IAdminAuthenticationPlugin(IAuthenticationPlugin):
     """Admin authentication plug-in base interface"""
 
@@ -254,6 +257,9 @@ SALT_SIZE = {
 }
 
 
+USERS_FOLDER_PLUGIN_LABEL = _("Users folder plug-in")
+
+
 class IUsersFolderPlugin(IAuthenticationPlugin, IDirectorySearchPlugin):
     """Local users folder interface"""
 
@@ -472,6 +478,9 @@ class ILocalUser(IAttributeAnnotatable):
 # Principals groups
 #
 
+GROUPS_FOLDER_PLUGIN_LABEL = _("Groups folder plug-in")
+
+
 class IGroupsFolderPlugin(IDirectorySearchPlugin, IGroupsAwareDirectoryPlugin):
     """Principals groups folder plug-in"""
 
